@@ -7,8 +7,10 @@
 #include "common.h"
 #include "auth.h"
 
-#define AUTHITEM_COMP	0
-#define AUTHITEM_SHARE	1
+typedef enum{
+    AUTHITEM_COMP,
+    AUTHITEM_SHARE
+} authitem_type;
 
 typedef struct{
     char		reserved[sizeof(LIST)];
@@ -25,11 +27,11 @@ typedef struct{
 } AuthInfo;
 
 typedef struct{
-    char	reserved[sizeof(LIST)];
-    AuthInfo	info;		
-    int		type;		// record type: comp/share
-    hstring	name;		// comp/share name
-    char	data[0];	// additional data
+    char	   reserved[sizeof(LIST)];
+    AuthInfo	   info;		
+    authitem_type  type;	// record type: comp/share
+    hstring	   name;	// comp/share name
+    char	   data[0];	// additional data
 } authitem;
 
 typedef struct{
@@ -46,7 +48,7 @@ authroot	root		= { { NULL, (time_t) 0 },
 				  };
 pthread_mutex_t	m_auth		= PTHREAD_MUTEX_INITIALIZER;
 
-void GetUserLogin(){
+void GetUserLogin(void){
     register struct passwd	*pw;
 
     if ((pw = getpwuid(getuid())) == NULL) return;
@@ -148,12 +150,12 @@ void ClearAuthInfo(AuthInfo *info){
     info->change_time = time(NULL);
 }
 
-authitem* MakeAuthItem(hstring *name, int type){
+authitem* MakeAuthItem(hstring *name, authitem_type type){
     char	*ptr;
     authitem	*item;
     size_t	len;
 
-    DPRINT(10, "name=%s, type=%d\n", name->string, type);
+    DPRINT(10, "name=%s, type=%d\n", name->string, (int)type);
 
     len = sizeof(authitem) + name->length + 1;
     if (type == AUTHITEM_COMP) len += sizeof(LIST);
@@ -187,7 +189,7 @@ authitem* find_in_authitem_list(LIST *list, hstring *name){
 // Try to find a computer/share information. If information was not
 // found we try to create it. After the search we place requested
 // information to the begining of the list to optimise future search
-authitem* get_entry(LIST *list, hstring *name, int type){
+authitem* get_entry(LIST *list, hstring *name, authitem_type type){
     authitem	*item;
 
     if ((item = find_in_authitem_list(list, name)) != NULL){
