@@ -1,7 +1,7 @@
 #ifndef __AUTH_H__
 #define __AUTH_H__
 
-void GetUserLogin();
+void GetUserLogin(void);
 
 int  SetSmbAuthData(const char *server, const char *share,
 	    const char *domain, const char *user, const char *password);
