@@ -26,11 +26,11 @@ const char* next_filename(const char *path);
 
 int  SetLogFile(char *filename);
 int  SetSMBNetFsDebugLevel(int level);
-int  GetSMBNetFsDebugLevel();
+int  GetSMBNetFsDebugLevel(void);
 
 void safe_copy(char *dst, const char *src, int dst_len);
 void debug_print(int level, const char *fmt, ...);
-void print_backtrace();
+void print_backtrace(void);
 
 /*
 #include <stdio.h>
