@@ -14,8 +14,8 @@ int SetShowDollarShares(int flag);
 int SetKDEworkaround(int count);
 int SetUnsafeTruncate(int flag);
 int SetFastShutdown(int flag);
-int GetFastShutdown();
+int GetFastShutdown(void);
 int SetUpdateTimeDelta(int delta);
-int GetUpdateTimeDelta();
+int GetUpdateTimeDelta(void);
 
 #endif /* __FUNCTION_H__ */
