@@ -5,7 +5,7 @@
 
 int    SetConfigFileUpdateInterval(int interval);
 int    isTimeForRereadConfig(time_t time);
-void   GetConfigDir();
-int    ReadConfig();
+void   GetConfigDir(void);
+int    ReadConfig(void);
 
 #endif /* __RECONFIGURE_H__ */
