@@ -6,6 +6,7 @@
 #include <libsmbclient.h>
 #include "list.h"
 
+#define SMBCTX_REGULAR		0x00
 #define SMBCTX_IS_BAD		0x01
 #define SMBCTX_NEEDS_CLEANUP	0x02
 #define SMBCTX_DO_NOT_UPDATE	0x04
@@ -23,14 +24,14 @@ typedef struct{
 
 int  SetSmbNetbiosName(const char *netbios_name);
 int  SetSmbDebugLevel(int level);
-int  GetSmbDebugLevel();
+int  GetSmbDebugLevel(void);
 int  SetMaxSmbCtxCount(int count);
-int  GetMaxSmbCtxCount();
+int  GetMaxSmbCtxCount(void);
 int  SetSmbCtxUpdateInterval(int interval);
-int  GetSmbCtxUpdateInterval();
+int  GetSmbCtxUpdateInterval(void);
 
-void    AllocateSmbCtx();
-void	DestroyUnusedCtx();
+void    AllocateSmbCtx(void);
+void	DestroyUnusedCtx(void);
 
 SmbCtx*	GetSmbCtx(const char *smbpath, int flags);
 void	ReleaseSmbCtx(SmbCtx *smb);
