@@ -66,7 +66,7 @@ int SetQueryBrowserFlag(int flag){
     return 1;
 }
 
-int GetQueryBrowserFlag(){
+int GetQueryBrowserFlag(void){
     int flag;
     
     pthread_mutex_lock(&m_smbitem);
@@ -76,7 +76,7 @@ int GetQueryBrowserFlag(){
     return flag;
 }
 
-smbitem* MakeItem(hstring *name, int type, hstring *link){
+smbitem* MakeItem(hstring *name, smbitem_type type, hstring *link){
     int		alloc_len;
     smbitem	*item;
     char	*ptr;
@@ -145,7 +145,7 @@ smbitem* FindSmbItem(LIST *list, hstring *name){
     return NULL;
 }
 
-smbitem* mkitem(LIST *list, hstring *name, int type, hstring *link){
+smbitem* mkitem(LIST *list, hstring *name, smbitem_type type, hstring *link){
     smbitem *item;
     
     if ((item = FindSmbItem(list, name)) != NULL){
@@ -177,7 +177,7 @@ void print_list(LIST *list, char *s){
     while(is_valid_elem(list, item)){
 	DPRINT(6, "%s%s[%d, %x], type=%d, link=%s[%d, %x], ref=%d, change_time=%d\n", s,
 	    item->name.string, item->name.length, item->name.hash,
-	    item->type, 
+	    (int)item->type, 
 	    item->link.string, item->link.length, item->link.hash,
 	    item->ref_count, (int)item->change_time);
 	    if (item->type == SMBITEM_GROUP)
@@ -273,7 +273,7 @@ void delete_old_item(LIST *list, time_t change_time){
 	tmp = item; item = next_elem(item);
 	if (tmp->type == SMBITEM_GROUP){
 	    delete_old_item((LIST*)tmp->data, change_time);
-	    if (first_elem((LIST*)tmp->data) != NULL) continue;
+	    if (!is_list_empty((LIST*)tmp->data)) continue;
 	}
 	if (tmp->change_time < change_time){
 	    remove_from_list(list, tmp);
@@ -372,7 +372,7 @@ int getdir(ARRAY *array, const char *path, int flag){
     return 1;
 }
 
-int GetPathType(const char *path, BUFFER *buf){
+file_type GetPathType(const char *path, BUFFER *buf){
     smbitem	*item, *item1;
     int		tree;
     hstring	name, name1;
@@ -382,7 +382,7 @@ int GetPathType(const char *path, BUFFER *buf){
     if (buf != NULL) buf->data[0] = '\0';
     
     path = filename_begin(path);
-    if (*path == '\0') return PATH_TO_DIR;
+    if (*path == '\0') return SMBNETFS_DIR;
 
     make_casehstring(&name, path, filename_len(path));
 
@@ -403,9 +403,9 @@ int GetPathType(const char *path, BUFFER *buf){
 	    if (!local2smb(buf->data + 6, path, BufferSize(buf) - 6))
 		return PATH_UNKNOWN;
 	}
-	if (*(path = next_filename(path)) == '\0') return PATH_TO_COMP;
-	if (*next_filename(path) == '\0') return PATH_TO_SHARE;
-	return PATH_TO_SMBFILE;
+	if (*(path = next_filename(path)) == '\0') return SMBNAME;
+	if (*next_filename(path) == '\0') return SMBSHARE;
+	return SMBFILE;
     }
 
     if (item->type == SMBITEM_LINK){
@@ -415,17 +415,17 @@ int GetPathType(const char *path, BUFFER *buf){
 	}
 	if (buf != NULL) safe_copy(buf->data, item->data, BufferSize(buf));
 	ReleaseSmbItem(item);
-	return PATH_TO_LINK;
+	return SMBNETFS_LINK;
     }
 
     if (item->type == SMBITEM_GROUP){
 	if (*(path = next_filename(path)) == '\0'){
 	    ReleaseSmbItem(item);
-	    return PATH_TO_DIR;
+	    return SMBNETFS_DIR;
 	}
-	
+
 	make_casehstring(&name1, path, filename_len(path));
-	
+
 	pthread_mutex_lock(&m_smbitem);
 	item1 = FindSmbItem((LIST*)item->data, &name1);
 	ReleaseElem(item);
@@ -446,9 +446,9 @@ int GetPathType(const char *path, BUFFER *buf){
 	}
 	if (buf != NULL) safe_copy(buf->data, item->data, BufferSize(buf));
 	ReleaseSmbItem(item);
-	return PATH_TO_LINK;
+	return SMBNETFS_LINK;
     };
-    
+
     DPRINT(0, "WARNING!!! BAD SMBITEM: %s\n", item->name.string);
     ReleaseSmbItem(item);
     return PATH_UNKNOWN;
@@ -501,7 +501,7 @@ void UpdateGroup(const char *group, BUFFER *buf1){
     ReleaseBuffer(buf2);
 }
 
-void UpdateRoot(){
+void UpdateRoot(void){
     BUFFER		*buf;
     SmbCtx		*smb;
     struct smbc_dirent	*dirent;
@@ -545,7 +545,7 @@ void UpdateRoot(){
     ReleaseBuffer(buf);    
 }
 
-void UpdateSambaTree(){
+void UpdateSambaTree(void){
     time_t die_time;
 
     pthread_mutex_lock(&m_smbitem);
