@@ -9,25 +9,29 @@
 #define USERPATH	0x01
 #define AUTOPATH	0x02
 
-#define SMBITEM_LINK	0
-#define SMBITEM_COMP	1
-#define SMBITEM_GROUP	2
+typedef enum{
+    SMBITEM_LINK,
+    SMBITEM_COMP,
+    SMBITEM_GROUP
+} smbitem_type;
 
-#define PATH_UNKNOWN		-1
-#define PATH_TO_DIR		0
-#define PATH_TO_LINK		1
-#define PATH_TO_COMP		2
-#define PATH_TO_SHARE		3
-#define PATH_TO_SMBFILE		4
+typedef enum{
+    PATH_UNKNOWN,
+    SMBNETFS_DIR,
+    SMBNETFS_LINK,
+    SMBNAME,
+    SMBSHARE,
+    SMBFILE
+} file_type;
 
 typedef struct{
-    char	reserved[sizeof(LIST)];
-    int		ref_count;	// the number of item references
-    time_t	change_time;	// item modification time
-    int		type;		// item type: comp/link/group
-    hstring	name;		// pointer to item name and its hash
-    hstring	link;		// pointer to link and its hash
-    char	data[0];	// internal data
+    char	  reserved[sizeof(LIST)];
+    int		  ref_count;	// the number of item references
+    time_t	  change_time;	// item modification time
+    smbitem_type  type;		// item type: comp/link/group
+    hstring	  name;		// pointer to item name and its hash
+    hstring	  link;		// pointer to link and its hash
+    char	  data[0];	// internal data
 } smbitem;
 
 extern BUFFERMANAGER   ConvertBuffer;
@@ -36,7 +40,7 @@ int    isTimeForRescanSambaTree(time_t time);
 int    SetSmbItemUpdateInterval(int interval);
 int    SetSmbItemTime2Live(int ttl);
 int    SetQueryBrowserFlag(int flag);
-int    GetQueryBrowserFlag();
+int    GetQueryBrowserFlag(void);
 
 int  mkgroup(const char *path, int flag);
 int  mkhost(const char *path, int flag);
@@ -47,8 +51,8 @@ void DeleteSmbItemArray(ARRAY *array);
 void RequestSmbItem(smbitem *item);
 void ReleaseSmbItem(smbitem* item);
 void DeleteOldSmbItem(time_t change_time, int flag);
-void UpdateSambaTree();
+void UpdateSambaTree(void);
 
-int  GetPathType(const char *path, BUFFER *buf);
+file_type GetPathType(const char *path, BUFFER *buf);
 
 #endif /* __SMBITEM_H__ */
